polib.MOEntry

Module polib :: Class MOEntry |
[hide private]
[frames] | no frames]

# Class MOEntry

source code

    _BaseEntry --+
                 |
                MOEntry

Represents a mo file entry.

Examples:

    >>> entry = MOEntry()
    >>> entry.msgid  = 'translate me !'
    >>> entry.msgstr = 'traduisez moi !'
    >>> print entry
    msgid "translate me !"
    msgstr "traduisez moi !"
    <BLANKLINE>

Instance Methods | [hide private]
__str__(self, wrapwidth=78) Return the string representation of the entry. | source code
Inherited from `_BaseEntry`: `__init__`, `__repr__` Inherited from `_BaseEntry` (private): `_decode`, `_str_field`

Method Details | [hide private]

### __str__(self, wrapwidth=78) (Informal representation operator) | source code
Return the string representation of the entry. Overrides: _BaseEntry.__str__